database

package
v0.313.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 11, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateCmd

func CreateCmd(ch *cmdutil.Helper) *cobra.Command

CreateCmd is the command for creating a database.

func DatabaseCmd

func DatabaseCmd(ch *cmdutil.Helper) *cobra.Command

DatabaseCmd encapsulates the commands for creating a database

func DeleteCmd

func DeleteCmd(ch *cmdutil.Helper) *cobra.Command

DeleteCmd is the Cobra command for deleting a database for an authenticated user.

func DumpCmd added in v0.25.0

func DumpCmd(ch *cmdutil.Helper) *cobra.Command

DumpCmd encapsulates the commands for dumping a database

func IPRestrictionCmd added in v0.313.0

func IPRestrictionCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionCmd manages Postgres IP restrictions for a database.

func IPRestrictionCreateCmd added in v0.313.0

func IPRestrictionCreateCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionCreateCmd creates an IP restriction entry.

func IPRestrictionDeleteCmd added in v0.313.0

func IPRestrictionDeleteCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionDeleteCmd deletes an IP restriction entry.

func IPRestrictionListCmd added in v0.313.0

func IPRestrictionListCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionListCmd lists IP restriction entries for a Postgres database.

func IPRestrictionShowCmd added in v0.313.0

func IPRestrictionShowCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionShowCmd shows a single IP restriction entry.

func IPRestrictionUpdateCmd added in v0.313.0

func IPRestrictionUpdateCmd(ch *cmdutil.Helper) *cobra.Command

IPRestrictionUpdateCmd updates an IP restriction entry.

func ListCmd

func ListCmd(ch *cmdutil.Helper) *cobra.Command

ListCmd is the command for listing all databases for an authenticated user.

func RestoreCmd added in v0.27.0

func RestoreCmd(ch *cmdutil.Helper) *cobra.Command

RestoreCmd encapsulates the commands for restore a database

func ShowCmd added in v0.13.0

func ShowCmd(ch *cmdutil.Helper) *cobra.Command

func UpdateCmd added in v0.313.0

func UpdateCmd(ch *cmdutil.Helper) *cobra.Command

UpdateCmd updates configurable database settings.

Types

type Database added in v0.14.0

type Database struct {
	Name                       string `header:"name" json:"name"`
	Kind                       string `header:"kind" json:"kind"`
	DefaultBranch              string `header:"default_branch" json:"default_branch"`
	RequireApprovalForDeploy   bool   `header:"require_approval_for_deploy" json:"require_approval_for_deploy"`
	RestrictBranchRegion       bool   `header:"restrict_branch_region" json:"restrict_branch_region"`
	AllowDataBranching         bool   `header:"allow_data_branching" json:"allow_data_branching"`
	ForeignKeysEnabled         bool   `header:"foreign_keys_enabled" json:"foreign_keys_enabled"`
	AutomaticMigrations        string `header:"automatic_migrations" json:"automatic_migrations"`
	MigrationFramework         string `header:"migration_framework" json:"migration_framework"`
	MigrationTableName         string `header:"migration_table_name" json:"migration_table_name"`
	InsightsRawQueries         bool   `header:"insights_raw_queries" json:"insights_raw_queries"`
	InsightsEnabled            bool   `header:"insights_enabled" json:"insights_enabled"`
	ProductionBranchWebConsole bool   `header:"production_branch_web_console" json:"production_branch_web_console"`
	CreatedAt                  int64  `header:"created_at,timestamp(ms|utc|human)" json:"created_at"`
	UpdatedAt                  int64  `header:"updated_at,timestamp(ms|utc|human)" json:"updated_at"`
	// contains filtered or unexported fields
}

Database is the human table for show/create/update, including settings.

func (*Database) MarshalCSVValue added in v0.17.0

func (d *Database) MarshalCSVValue() interface{}

func (*Database) MarshalJSON added in v0.14.0

func (d *Database) MarshalJSON() ([]byte, error)

type Databases added in v0.14.0

type Databases []*databaseListItem

Databases represents a slice of database list rows.

type IPRestrictionEntry added in v0.313.0

type IPRestrictionEntry struct {
	ID          string `header:"id" json:"id"`
	Schema      string `header:"schema" json:"schema"`
	Role        string `header:"role" json:"role"`
	CIDRs       string `header:"cidrs" json:"cidrs"`
	Description string `header:"description" json:"description"`
	Actor       string `header:"actor" json:"actor"`
	CreatedAt   int64  `header:"created_at,timestamp(ms|utc|human)" json:"created_at"`
	UpdatedAt   int64  `header:"updated_at,timestamp(ms|utc|human)" json:"updated_at"`
	// contains filtered or unexported fields
}

IPRestrictionEntry is the human/JSON/CSV view of a Postgres IP restriction entry.

func (*IPRestrictionEntry) MarshalCSVValue added in v0.313.0

func (e *IPRestrictionEntry) MarshalCSVValue() interface{}

func (*IPRestrictionEntry) MarshalJSON added in v0.313.0

func (e *IPRestrictionEntry) MarshalJSON() ([]byte, error)

Jump to